@@ -76,6 +76,8 @@ class CongestionSeriesSplit(Enum):
     VesselTypeOil = "vesselTypeOil"  #:
     VesselOperations = "VesselOperations"  #:
     WaitingStatus = "waitingStatus"  #:
+    Product = "product"  #:
+    Grade = "grade"  #:
 
 
 class CongestionSeriesUnit(Enum):
@@ -142,6 +144,7 @@ class FleetDevelopmentSeriesMetric(Enum):
     Available = "available"  #:
     Deliveries = "deliveries"  #:
     Scrapping = "scrapping"  #:
+    Contracting = "contracting"  #:
 
 
 class FleetDevelopmentSeriesPeriod(Enum):
@@ -338,6 +341,7 @@ class FleetDevelopmentVesselsMetric(Enum):
     Available = "available"  #:
     Deliveries = "deliveries"  #:
     Scrapping = "scrapping"  #:
+    Contracting = "contracting"  #:
 
 
 class FleetMetricsAlgo(Enum):
