@@ -7,6 +7,7 @@ from pandas import DataFrame
 from kpler.sdk import Platform
 from kpler.sdk.client import KplerClient
 from kpler.sdk.configuration import Configuration
+from kpler.sdk.exceptions import WithProductEstimationPlatformException
 from kpler.sdk.helpers import (
     process_bool_parameter,
     process_date_parameter,
@@ -65,7 +66,8 @@ class Trades(KplerClient):
         with_forecast: Optional[bool] = None,
         with_intra_country: Optional[bool] = None,
         columns: Optional[List[str]] = None,
-        with_freight_view: bool = False,
+        with_freight_view: Optional[bool] = False,
+        with_product_estimation: Optional[bool] = False,
     ) -> DataFrame:
         """
 
@@ -86,7 +88,7 @@ class Trades(KplerClient):
             with_intra_country: Optional[bool] By default: withIntraCountry=true. Takes into account the trades within the selected region. Use ["true", "false"]
             columns: Optional[List[str]] Retrieve all available columns when set to "all"
             with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
-
+            with_product_estimation: bool By default withProductEstimation=False. Activate the product estimation feature for CPP trades only. When set to true, the estimated product will overwrite the existing product information.
         Examples:
             >>> from datetime import date, timedelta
             ... from kpler.sdk.resources.trades import Trades
@@ -119,6 +121,9 @@ class Trades(KplerClient):
                 "Washington","crude","ANS","2020-10-19 14:48:00","2020-10-27 00:00:00","Valdez","San Francisco"
                 "...","...","...","...","...","...","..."
         """
+
+        self.with_product_estimation = with_product_estimation
+
         query_parameters: Dict[str, Optional[Any]] = {
             "size": size,
             "vessels": process_list_parameter(vessels),
@@ -136,5 +141,10 @@ class Trades(KplerClient):
             "withIntraCountry": process_bool_parameter(with_intra_country),
             "columns": process_list_parameter(columns),
             "withFreightView": process_bool_parameter(with_freight_view),
+            "withProductEstimation": process_bool_parameter(with_product_estimation),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
+
+    def validate(self):
+        if self.with_product_estimation and self.configuration.platform != Platform.Liquids:
+            raise WithProductEstimationPlatformException()
